==> OpenJDK-1.7.0.45-i686-bin.tar.xz: com/sun/swing/internal/plaf/metal/resources/metal_sv.java <==
package com.sun.swing.internal.plaf.metal.resources;

import java.util.ListResourceBundle;

public final class metal_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "FileChooser.detailsViewActionLabel.textAndMnemonic", "Detaljer" },
            { "FileChooser.detailsViewButtonAccessibleName", "Detaljer" },
            { "FileChooser.detailsViewButtonToolTip.textAndMnemonic", "Detaljer" },
            { "FileChooser.fileAttrHeader.textAndMnemonic", "Attribut" },
            { "FileChooser.fileDateHeader.textAndMnemonic", "\u00C4ndrad" },
            { "FileChooser.fileNameHeader.textAndMnemonic", "Namn" },
            { "FileChooser.fileNameLabel.textAndMnemonic", "Fil&namn:" },
            { "FileChooser.fileSizeHeader.textAndMnemonic", "Storlek" },
            { "FileChooser.fileTypeHeader.textAndMnemonic", "Typ" },
            { "FileChooser.filesOfTypeLabel.textAndMnemonic", "Mapp&namn:" },
            { "FileChooser.folderNameLabel.textAndMnemonic", "Mapp&namn:" },
            { "FileChooser.homeFolderAccessibleName", "Hem" },
            { "FileChooser.homeFolderToolTip.textAndMnemonic", "Hem" },
            { "FileChooser.listViewActionLabel.textAndMnemonic", "Lista" },
            { "FileChooser.listViewButtonAccessibleName", "Lista" },
            { "FileChooser.listViewButtonToolTip.textAndMnemonic", "Lista" },
            { "FileChooser.lookInLabel.textAndMnemonic", "Leta &i:" },
            { "FileChooser.newFolderAccessibleName", "Ny mapp" },
            { "FileChooser.newFolderActionLabel.textAndMnemonic", "Ny mapp" },
            { "FileChooser.newFolderToolTip.textAndMnemonic", "Skapa ny mapp" },
            { "FileChooser.openButton.textAndMnemonic", "\u00D6ppna" },
            { "FileChooser.refreshActionLabel.textAndMnemonic", "F\u00F6rnya" },
            { "FileChooser.saveButton.textAndMnemonic", "Spara" },
            { "FileChooser.saveInLabel.textAndMnemonic", "Spara i:" },
            { "FileChooser.upFolderAccessibleName", "Upp" },
            { "FileChooser.upFolderToolTip.textAndMnemonic", "Upp en niv\u00E5" },
            { "FileChooser.viewMenuLabel.textAndMnemonic", "Vy" },
            { "MetalTitlePane.close.titleAndMnemonic", "&St\u00E4ng" },
            { "MetalTitlePane.iconify.titleAndMnemonic", "Minim&era" },
            { "MetalTitlePane.maximize.titleAndMnemonic", "Ma&ximera" },
            { "MetalTitlePane.restore.titleAndMnemonic", "&\u00C5terst\u00E4ll" },
        };
    }
}

==> OpenJDK-1.7.0.65-i686-bin.tar.xz: com/sun/swing/internal/plaf/metal/resources/metal_sv.java <==
package com.sun.swing.internal.plaf.metal.resources;

import java.util.ListResourceBundle;

public final class metal_sv extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "FileChooser.detailsViewActionLabel.textAndMnemonic", "Detaljer" },
            { "FileChooser.detailsViewButtonAccessibleName", "Detaljer" },
            { "FileChooser.detailsViewButtonToolTip.textAndMnemonic", "Detaljer" },
            { "FileChooser.fileAttrHeader.textAndMnemonic", "Attribut" },
            { "FileChooser.fileDateHeader.textAndMnemonic", "\u00C4ndrad" },
            { "FileChooser.fileNameHeader.textAndMnemonic", "Namn" },
            { "FileChooser.fileNameLabel.textAndMnemonic", "&Fil:" },
            { "FileChooser.fileSizeHeader.textAndMnemonic", "Storlek" },
            { "FileChooser.fileTypeHeader.textAndMnemonic", "Typ" },
            { "FileChooser.filesOfTypeLabel.textAndMnemonic", "Mapp&namn:" },
            { "FileChooser.folderNameLabel.textAndMnemonic", "&Mapp:" },
            { "FileChooser.homeFolderAccessibleName", "Hem" },
            { "FileChooser.homeFolderToolTip.textAndMnemonic", "Hem" },
            { "FileChooser.listViewActionLabel.textAndMnemonic", "Lista" },
            { "FileChooser.listViewButtonAccessibleName", "Lista" },
            { "FileChooser.listViewButtonToolTip.textAndMnemonic", "Lista" },
            { "FileChooser.lookInLabel.textAndMnemonic", "Leta &i:" },
            { "FileChooser.newFolderAccessibleName", "Ny mapp" },
            { "FileChooser.newFolderActionLabel.textAndMnemonic", "Ny mapp" },
            { "FileChooser.newFolderToolTip.textAndMnemonic", "Skapa ny mapp" },
            { "FileChooser.openButton.textAndMnemonic", "\u00D6ppna" },
            { "FileChooser.refreshActionLabel.textAndMnemonic", "F\u00F6rnya" },
            { "FileChooser.saveButton.textAndMnemonic", "Spara" },
            { "FileChooser.saveInLabel.textAndMnemonic", "Spara i:" },
            { "FileChooser.upFolderAccessibleName", "Upp" },
            { "FileChooser.upFolderToolTip.textAndMnemonic", "Upp en niv\u00E5" },
            { "FileChooser.viewMenuLabel.textAndMnemonic", "Vy" },
            { "MetalTitlePane.close.titleAndMnemonic", "&St\u00E4ng" },
            { "MetalTitlePane.iconify.titleAndMnemonic", "Minim&era" },
            { "MetalTitlePane.maximize.titleAndMnemonic", "Ma&ximera" },
            { "MetalTitlePane.restore.titleAndMnemonic", "&\u00C5terst\u00E4ll" },
        };
    }
}
